pub struct EthereumEventVoteRecord {
pub event: Option<Any>,
pub votes: Vec<String>,
pub accepted: bool,
}Expand description
EthereumEventVoteRecord is an event that is pending of confirmation by 2/3 of the signer set. The event is then attested and executed in the state machine once the required threshold is met.
Fields
event: Option<Any>votes: Vec<String>accepted: boolTrait Implementations
Sourceimpl Clone for EthereumEventVoteRecord
impl Clone for EthereumEventVoteRecord
Sourcefn clone(&self) -> EthereumEventVoteRecord
fn clone(&self) -> EthereumEventVoteRecord
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EthereumEventVoteRecord
impl Debug for EthereumEventVoteRecord
Sourceimpl Default for EthereumEventVoteRecord
impl Default for EthereumEventVoteRecord
Sourceimpl Message for EthereumEventVoteRecord
impl Message for EthereumEventVoteRecord
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message to a buffer. Read more
Sourcefn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn decode<B>(buf: B) -> Result<Self, DecodeError>
fn decode<B>(buf: B) -> Result<Self, DecodeError>
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
fn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for EthereumEventVoteRecord
impl PartialEq for EthereumEventVoteRecord
impl StructuralPartialEq for EthereumEventVoteRecord