pub struct LatestEthereumBlockHeight {
pub ethereum_height: u64,
pub cosmos_height: u64,
}Expand description
LatestEthereumBlockHeight defines the latest observed ethereum block height and the corresponding timestamp value in nanoseconds.
Fields
ethereum_height: u64cosmos_height: u64Trait Implementations
Sourceimpl Clone for LatestEthereumBlockHeight
impl Clone for LatestEthereumBlockHeight
Sourcefn clone(&self) -> LatestEthereumBlockHeight
fn clone(&self) -> LatestEthereumBlockHeight
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LatestEthereumBlockHeight
impl Debug for LatestEthereumBlockHeight
Sourceimpl Default for LatestEthereumBlockHeight
impl Default for LatestEthereumBlockHeight
Sourceimpl Message for LatestEthereumBlockHeight
impl Message for LatestEthereumBlockHeight
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message to a buffer. Read more
Sourcefn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn decode<B>(buf: B) -> Result<Self, DecodeError>
fn decode<B>(buf: B) -> Result<Self, DecodeError>
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
fn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.impl StructuralPartialEq for LatestEthereumBlockHeight