pub struct QueryClient<T> { /* private fields */ }Expand description
Query defines the gRPC querier service
Implementations
Sourceimpl QueryClient<Channel>
impl QueryClient<Channel>
Sourceimpl<T> QueryClient<T>where
T: GrpcService<BoxBody>,
T::ResponseBody: Body + HttpBody + Send + 'static,
T::Error: Into<StdError>,
<T::ResponseBody as HttpBody>::Error: Into<StdError> + Send,
impl<T> QueryClient<T>where
T: GrpcService<BoxBody>,
T::ResponseBody: Body + HttpBody + Send + 'static,
T::Error: Into<StdError>,
<T::ResponseBody as HttpBody>::Error: Into<StdError> + Send,
pub fn new(inner: T) -> Self
pub fn with_interceptor(inner: T, interceptor: impl Into<Interceptor>) -> Self
Sourcepub async fn params(
&mut self,
request: impl IntoRequest<ParamsRequest>,
) -> Result<Response<ParamsResponse>, Status>
pub async fn params( &mut self, request: impl IntoRequest<ParamsRequest>, ) -> Result<Response<ParamsResponse>, Status>
Module parameters query
Sourcepub async fn signer_set_tx(
&mut self,
request: impl IntoRequest<SignerSetTxRequest>,
) -> Result<Response<SignerSetTxResponse>, Status>
pub async fn signer_set_tx( &mut self, request: impl IntoRequest<SignerSetTxRequest>, ) -> Result<Response<SignerSetTxResponse>, Status>
get info on individual outgoing data
pub async fn latest_signer_set_tx( &mut self, request: impl IntoRequest<LatestSignerSetTxRequest>, ) -> Result<Response<SignerSetTxResponse>, Status>
pub async fn batch_tx( &mut self, request: impl IntoRequest<BatchTxRequest>, ) -> Result<Response<BatchTxResponse>, Status>
pub async fn contract_call_tx( &mut self, request: impl IntoRequest<ContractCallTxRequest>, ) -> Result<Response<ContractCallTxResponse>, Status>
Sourcepub async fn signer_set_txs(
&mut self,
request: impl IntoRequest<SignerSetTxsRequest>,
) -> Result<Response<SignerSetTxsResponse>, Status>
pub async fn signer_set_txs( &mut self, request: impl IntoRequest<SignerSetTxsRequest>, ) -> Result<Response<SignerSetTxsResponse>, Status>
get collections of outgoing traffic from the bridge
pub async fn batch_txs( &mut self, request: impl IntoRequest<BatchTxsRequest>, ) -> Result<Response<BatchTxsResponse>, Status>
pub async fn contract_call_txs( &mut self, request: impl IntoRequest<ContractCallTxsRequest>, ) -> Result<Response<ContractCallTxsResponse>, Status>
Sourcepub async fn signer_set_tx_confirmations(
&mut self,
request: impl IntoRequest<SignerSetTxConfirmationsRequest>,
) -> Result<Response<SignerSetTxConfirmationsResponse>, Status>
pub async fn signer_set_tx_confirmations( &mut self, request: impl IntoRequest<SignerSetTxConfirmationsRequest>, ) -> Result<Response<SignerSetTxConfirmationsResponse>, Status>
TODO: can/should we group these into one endpoint?
pub async fn batch_tx_confirmations( &mut self, request: impl IntoRequest<BatchTxConfirmationsRequest>, ) -> Result<Response<BatchTxConfirmationsResponse>, Status>
pub async fn contract_call_tx_confirmations( &mut self, request: impl IntoRequest<ContractCallTxConfirmationsRequest>, ) -> Result<Response<ContractCallTxConfirmationsResponse>, Status>
Sourcepub async fn unsigned_signer_set_txs(
&mut self,
request: impl IntoRequest<UnsignedSignerSetTxsRequest>,
) -> Result<Response<UnsignedSignerSetTxsResponse>, Status>
pub async fn unsigned_signer_set_txs( &mut self, request: impl IntoRequest<UnsignedSignerSetTxsRequest>, ) -> Result<Response<UnsignedSignerSetTxsResponse>, Status>
pending ethereum signature queries for orchestrators to figure out which signatures they are missing TODO: can/should we group this into one endpoint?
pub async fn unsigned_batch_txs( &mut self, request: impl IntoRequest<UnsignedBatchTxsRequest>, ) -> Result<Response<UnsignedBatchTxsResponse>, Status>
pub async fn unsigned_contract_call_txs( &mut self, request: impl IntoRequest<UnsignedContractCallTxsRequest>, ) -> Result<Response<UnsignedContractCallTxsResponse>, Status>
pub async fn last_submitted_ethereum_event( &mut self, request: impl IntoRequest<LastSubmittedEthereumEventRequest>, ) -> Result<Response<LastSubmittedEthereumEventResponse>, Status>
Sourcepub async fn batch_tx_fees(
&mut self,
request: impl IntoRequest<BatchTxFeesRequest>,
) -> Result<Response<BatchTxFeesResponse>, Status>
pub async fn batch_tx_fees( &mut self, request: impl IntoRequest<BatchTxFeesRequest>, ) -> Result<Response<BatchTxFeesResponse>, Status>
Queries the fees for all pending batches, results are returned in sdk.Coin (fee_amount_int)(contract_address) style
Sourcepub async fn erc20_to_denom(
&mut self,
request: impl IntoRequest<Erc20ToDenomRequest>,
) -> Result<Response<Erc20ToDenomResponse>, Status>
pub async fn erc20_to_denom( &mut self, request: impl IntoRequest<Erc20ToDenomRequest>, ) -> Result<Response<Erc20ToDenomResponse>, Status>
Query for info about denoms tracked by gravity
Sourcepub async fn denom_to_erc20_params(
&mut self,
request: impl IntoRequest<DenomToErc20ParamsRequest>,
) -> Result<Response<DenomToErc20ParamsResponse>, Status>
pub async fn denom_to_erc20_params( &mut self, request: impl IntoRequest<DenomToErc20ParamsRequest>, ) -> Result<Response<DenomToErc20ParamsResponse>, Status>
Query for how gravity expects an erc-20 to be created
Sourcepub async fn denom_to_erc20(
&mut self,
request: impl IntoRequest<DenomToErc20Request>,
) -> Result<Response<DenomToErc20Response>, Status>
pub async fn denom_to_erc20( &mut self, request: impl IntoRequest<DenomToErc20Request>, ) -> Result<Response<DenomToErc20Response>, Status>
Query for info about denoms tracked by gravity
Sourcepub async fn batched_send_to_ethereums(
&mut self,
request: impl IntoRequest<BatchedSendToEthereumsRequest>,
) -> Result<Response<BatchedSendToEthereumsResponse>, Status>
pub async fn batched_send_to_ethereums( &mut self, request: impl IntoRequest<BatchedSendToEthereumsRequest>, ) -> Result<Response<BatchedSendToEthereumsResponse>, Status>
Query for batch send to ethereums
Sourcepub async fn unbatched_send_to_ethereums(
&mut self,
request: impl IntoRequest<UnbatchedSendToEthereumsRequest>,
) -> Result<Response<UnbatchedSendToEthereumsResponse>, Status>
pub async fn unbatched_send_to_ethereums( &mut self, request: impl IntoRequest<UnbatchedSendToEthereumsRequest>, ) -> Result<Response<UnbatchedSendToEthereumsResponse>, Status>
Query for unbatched send to ethereums
Sourcepub async fn delegate_keys_by_validator(
&mut self,
request: impl IntoRequest<DelegateKeysByValidatorRequest>,
) -> Result<Response<DelegateKeysByValidatorResponse>, Status>
pub async fn delegate_keys_by_validator( &mut self, request: impl IntoRequest<DelegateKeysByValidatorRequest>, ) -> Result<Response<DelegateKeysByValidatorResponse>, Status>
delegate keys
pub async fn delegate_keys_by_ethereum_signer( &mut self, request: impl IntoRequest<DelegateKeysByEthereumSignerRequest>, ) -> Result<Response<DelegateKeysByEthereumSignerResponse>, Status>
pub async fn delegate_keys_by_orchestrator( &mut self, request: impl IntoRequest<DelegateKeysByOrchestratorRequest>, ) -> Result<Response<DelegateKeysByOrchestratorResponse>, Status>
pub async fn delegate_keys( &mut self, request: impl IntoRequest<DelegateKeysRequest>, ) -> Result<Response<DelegateKeysResponse>, Status>